@@ -4,6 +4,8 @@ import matplotlib.transforms as mtransforms
 import matplotlib.pyplot as plt
 import matplotlib.text as mtext
 
+import mplhep
+
 
 class ExpText(mtext.Text):
     def __repr__(self):
@@ -143,7 +145,7 @@ def _exp_text(
         )
     elif loc == 1:
         _t = mtransforms.offset_copy(
-            exp._transform,
+            exptext._transform,
             x=_exp_xoffset,
             y=-exptext.get_window_extent().height / _dpi,
             units="inches",
@@ -151,7 +153,7 @@ def _exp_text(
         )
     elif loc == 2:
         _t = mtransforms.offset_copy(
-            exp._transform,
+            exptext._transform,
             y=-exptext.get_window_extent().height / _dpi,
             units="inches",
             fig=ax.figure,
@@ -281,8 +283,9 @@ def _exp_label(
         _lumi = rlabel
     else:
         if lumi is not None:
-            _lumi = r"{lumi}, {year} (13 TeV)".format(
-                lumi=str(lumi) + r" $\mathrm{fb^{-1}}$", year=str(year)
+            _lumi = r"{lumi}{year} (13 TeV)".format(
+                lumi=str(lumi) + r" $\mathrm{fb^{-1}}$",
+                year=", " + str(year) if len(str(year)) > 0 else "",
             )
         else:
             _lumi = "{} (13 TeV)".format(str(year))
